==> cdm-4.5.2-sources.jar: ucar/nc2/ft/point/MultipleNestedPointCollectionImpl.java <==
/*
 * Copyright 1998-2014 University Corporation for Atmospheric Research/Unidata
 *
 *   Portions of this software were developed by the Unidata Program at the
 *   University Corporation for Atmospheric Research.
 *
 *   Access and use of this software shall impose the following obligations
 *   and understandings on the user. The user is granted the right, without
 *   any fee or cost, to use, copy, modify, alter, enhance and distribute
 *   this software, and any derivative works thereof, and its supporting
 *   documentation for any purpose whatsoever, provided that this entire
 *   notice appears in all copies of the software, derivative works and
 *   supporting documentation.  Further, UCAR requests that the user credit
 *   UCAR/Unidata in any publications that result from the use of this
 *   software or in any product that includes this software. The names UCAR
 *   and/or Unidata, however, may not be used in any advertising or publicity
 *   to endorse or promote any products or commercial entity unless specific
 *   written permission is obtained from UCAR/Unidata. The user also
 *   understands that UCAR/Unidata is not obligated to provide the user with
 *   any support, consulting, training or assistance of any kind with regard
 *   to the use, operation and performance of this software nor to provide
 *   the user with any updates, revisions, new versions or "bug fixes."
 *
 *   THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 *   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 *   INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 *   FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 *   NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 *   WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */
package ucar.nc2.ft.point;

import ucar.nc2.Variable;
import ucar.nc2.ft.NestedPointFeatureCollection;
import ucar.nc2.ft.PointFeatureCollection;
import ucar.nc2.ft.PointFeatureIterator;
import ucar.nc2.ft.PointFeatureCollectionIterator;
import ucar.nc2.time.CalendarDateRange;
import ucar.nc2.units.DateRange;
import ucar.nc2.constants.FeatureType;
import ucar.nc2.units.DateUnit;
import ucar.unidata.geoloc.LatLonRect;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * Abstract superclass for multiply nested NestedPointFeatureCollection
 * Subclass must supply getNestedPointFeatureCollectionIterator().
 *
 * @author caron
 * @since Mar 26, 2008
 */
public abstract class MultipleNestedPointCollectionImpl implements NestedPointFeatureCollection {
  protected String name;
  protected DateUnit timeUnit;
  protected String altUnits;
  protected FeatureType collectionFeatureType;
  protected int npts;
  protected List<Variable> extras;

  protected MultipleNestedPointCollectionImpl(String name, DateUnit timeUnit, String altUnits, FeatureType collectionFeatureType) {
    this.name = name;
    this.timeUnit = timeUnit;
    this.altUnits = altUnits;
    this.collectionFeatureType = collectionFeatureType;
    this.npts = -1;
  }

  @Override
  public String getName() {
    return name;
  }

  @Override
  public DateUnit getTimeUnit() {
    return timeUnit;
  }

  @Override
  public String getAltUnits() {
    return altUnits;
  }

  public List<Variable> getExtraVariables() { return (extras == null) ? new ArrayList<Variable>() : extras; }

  public int size() {
    return npts;
  }

  protected void setSize( int npts) {
    this.npts = npts;
  }

  public boolean isMultipleNested() {
    return true;
  }

  // All features in this collection have this feature type
  public FeatureType getCollectionFeatureType() {
    return collectionFeatureType;
  }

  public PointFeatureCollectionIterator getPointFeatureCollectionIterator(int bufferSize) throws IOException {
    throw new UnsupportedOperationException(getClass().getName() + " (multipleNested) PointFeatureCollection does not implement getPointFeatureCollectionIterator()");
  }

  // flatten into a PointFeatureCollection
  // if empty, may return null
  public PointFeatureCollection flatten(LatLonRect boundingBox, CalendarDateRange dateRange) throws IOException {
    return new NestedPointFeatureCollectionFlatten(this, boundingBox, dateRange);
  }

  public PointFeatureCollection flatten(LatLonRect boundingBox, DateRange dateRange) throws IOException {
    return flatten( boundingBox, CalendarDateRange.of(dateRange));
  }

  private class NestedPointFeatureCollectionFlatten extends PointCollectionImpl {
    protected MultipleNestedPointCollectionImpl from;

    NestedPointFeatureCollectionFlatten(MultipleNestedPointCollectionImpl from, LatLonRect filter_bb, CalendarDateRange filter_date) {
      super(from.getName(), from.getTimeUnit(), from.getAltUnits());
      this.from = from;
      this.boundingBox = filter_bb;
      this.dateRange = filter_date;
    }

    public PointFeatureIterator getPointFeatureIterator(int bufferSize) throws IOException {
      // LOOK need the isMultipleNested case
      return new PointIteratorFlatten(from.getPointFeatureCollectionIterator(bufferSize), this.boundingBox, this.dateRange);
    }

  }
}

==> cdm-4.5.5-sources.jar: ucar/nc2/ft/point/MultipleNestedPointCollectionImpl.java <==
/*
 * Copyright 1998-2014 University Corporation for Atmospheric Research/Unidata
 *
 *   Portions of this software were developed by the Unidata Program at the
 *   University Corporation for Atmospheric Research.
 *
 *   Access and use of this software shall impose the following obligations
 *   and understandings on the user. The user is granted the right, without
 *   any fee or cost, to use, copy, modify, alter, enhance and distribute
 *   this software, and any derivative works thereof, and its supporting
 *   documentation for any purpose whatsoever, provided that this entire
 *   notice appears in all copies of the software, derivative works and
 *   supporting documentation.  Further, UCAR requests that the user credit
 *   UCAR/Unidata in any publications that result from the use of this
 *   software or in any product that includes this software. The names UCAR
 *   and/or Unidata, however, may not be used in any advertising or publicity
 *   to endorse or promote any products or commercial entity unless specific
 *   written permission is obtained from UCAR/Unidata. The user also
 *   understands that UCAR/Unidata is not obligated to provide the user with
 *   any support, consulting, training or assistance of any kind with regard
 *   to the use, operation and performance of this software nor to provide
 *   the user with any updates, revisions, new versions or "bug fixes."
 *
 *   THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 *   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 *   INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 *   FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 *   NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 *   WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */
package ucar.nc2.ft.point;

import ucar.nc2.Variable;
import ucar.nc2.ft.NestedPointFeatureCollection;
import ucar.nc2.ft.PointFeatureCollection;
import ucar.nc2.ft.PointFeatureIterator;
import ucar.nc2.ft.PointFeatureCollectionIterator;
import ucar.nc2.time.CalendarDateRange;
import ucar.nc2.units.DateRange;
import ucar.nc2.constants.FeatureType;
import ucar.nc2.units.DateUnit;
import ucar.unidata.geoloc.LatLonRect;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * Abstract superclass for multiply nested NestedPointFeatureCollection
 * Subclass must supply getNestedPointFeatureCollectionIterator().
 *
 * @author caron
 * @since Mar 26, 2008
 */
public abstract class MultipleNestedPointCollectionImpl implements NestedPointFeatureCollection {
  protected String name;
  protected DateUnit timeUnit;
  protected String altUnits;
  protected FeatureType collectionFeatureType;
  protected int npts;
  protected List<Variable> extras;

  protected MultipleNestedPointCollectionImpl(String name, DateUnit timeUnit, String altUnits, FeatureType collectionFeatureType) {
    this.name = name;
    this.timeUnit = timeUnit;
    this.altUnits = altUnits;
    this.collectionFeatureType = collectionFeatureType;
    this.npts = -1;
  }

  @Override
  public String getName() {
    return name;
  }

  @Override
  public DateUnit getTimeUnit() {
    return timeUnit;
  }

  @Override
  public String getAltUnits() {
    return altUnits;
  }

  public List<Variable> getExtraVariables() { return (extras == null) ? new ArrayList<Variable>() : extras; }

  public int size() {
    return npts;
  }

  protected void setSize( int npts) {
    this.npts = npts;
  }

  public boolean isMultipleNested() {
    return true;
  }

  // All features in this collection have this feature type
  public FeatureType getCollectionFeatureType() {
    return collectionFeatureType;
  }

  public PointFeatureCollectionIterator getPointFeatureCollectionIterator(int bufferSize) throws IOException {
    throw new UnsupportedOperationException(getClass().getName() + " (multipleNested) PointFeatureCollection does not implement getPointFeatureCollectionIterator()");
  }

  // flatten into a PointFeatureCollection
  // if empty, may return null
  public PointFeatureCollection flatten(LatLonRect boundingBox, CalendarDateRange dateRange) throws IOException {
    return new NestedPointFeatureCollectionFlatten(this, boundingBox, dateRange);
  }

  public PointFeatureCollection flatten(LatLonRect boundingBox, DateRange dateRange) throws IOException {
    return flatten( boundingBox, CalendarDateRange.of(dateRange));
  }

  private static class NestedPointFeatureCollectionFlatten extends PointCollectionImpl {
    protected MultipleNestedPointCollectionImpl from;

    NestedPointFeatureCollectionFlatten(MultipleNestedPointCollectionImpl from, LatLonRect filter_bb, CalendarDateRange filter_date) {
      super(from.getName(), from.getTimeUnit(), from.getAltUnits());
      this.from = from;
      this.boundingBox = filter_bb;
      this.dateRange = filter_date;
    }

    public PointFeatureIterator getPointFeatureIterator(int bufferSize) throws IOException {
      // LOOK need the isMultipleNested case
      return new PointIteratorFlatten(from.getPointFeatureCollectionIterator(bufferSize), this.boundingBox, this.dateRange);
    }

  }
}
